@@ -47,6 +47,8 @@ class CreateMetricOperator(BaseOperator):
             notifications = c.get("notifications", [])
             metric_name = c.get("metric_name")
             should_backfill = c.get("should_backfill", False)
+            lookback_type = c.get("lookback_type", "METRIC_TIME_LOOKBACK_TYPE")
+            lookback_days = c.get("lookback_days", 2)
             if metric_name is None:
                 raise Exception("Metric name must be present in configuration", c)
             table = self._get_table_for_name(schema_name, table_name)
@@ -55,7 +57,7 @@ class CreateMetricOperator(BaseOperator):
             existing_metric = self._get_existing_metric(table, column_name, metric_name)
             metric = self._get_metric_object(existing_metric, table, notifications, column_name,
                                              update_schedule, delay_at_update, timezone, default_check_frequency_hours,
-                                             metric_name)
+                                             metric_name, lookback_type, lookback_days)
             logging.info("Sending metric to create: %s", metric)
             bigeye_post_hook = self.get_hook('POST')
             result = bigeye_post_hook.run("api/v1/metrics",
@@ -71,8 +73,8 @@ class CreateMetricOperator(BaseOperator):
     def get_hook(self, method) -> HttpHook:
         return HttpHook(http_conn_id=self.connection_id, method=method)
 
-    def _get_metric_object(self, existing_metric, table, notifications, column_name,
-                           update_schedule, delay_at_update, timezone, default_check_frequency_hours, metric_name):
+    def _get_metric_object(self, existing_metric, table, notifications, column_name, update_schedule, delay_at_update,
+                           timezone, default_check_frequency_hours, metric_name, lookback_type, lookback_days):
         if self._is_freshness_metric(metric_name):
             metric_name = self._get_freshness_metric_name_for_field(table, column_name)
             if update_schedule is None:
@@ -96,18 +98,23 @@ class CreateMetricOperator(BaseOperator):
                     "columnName": column_name
                 }
             ],
-            "lookback": {
-                "intervalType": "DAYS_TIME_INTERVAL_TYPE",
-                "intervalValue": 1
-            },
             "notificationChannels": self._get_notification_channels(notifications)
         }
+        for field in table["fields"]:
+            if field["loadedDateField"]:
+                metric["lookbackType"] = lookback_type
+                metric["lookback"] = {
+                    "intervalType": "DAYS_TIME_INTERVAL_TYPE",
+                    "intervalValue": lookback_days
+                }
         if existing_metric is None:
             return metric
         else:
             existing_metric["thresholds"] = metric["thresholds"]
             existing_metric["notificationChannels"] = metric.get("notificationChannels", [])
             existing_metric["scheduleFrequency"] = metric["scheduleFrequency"]
+            existing_metric["lookbackType"] = metric["lookbackType"]
+            existing_metric["lookback"] = metric["lookback"]
             return existing_metric
 
     def _is_freshness_metric(self, metric_name):
